﻿using Microsoft.AspNetCore.Mvc;
using Newtonsoft.Json.Serialization;
using OASystem.API.OAMethodLib;
using OASystem.Domain.Dtos.Groups;
using OASystem.Domain.Entities.Business;
using OASystem.Domain.Entities.Groups;
using OASystem.Domain.ViewModels.Groups;
using OASystem.Infrastructure.Repositories.Groups;
using static OpenAI.GPT3.ObjectModels.SharedModels.IOpenAiModels;

namespace OASystem.API.Controllers
{
    /// <summary>
    /// 团组相关
    /// </summary>
    //[Authorize]
    [Route("api/[controller]/[action]")]
    public class GroupsController : ControllerBase
    {
        private readonly GrpScheduleRepository _grpScheduleRep;
        private readonly IMapper _mapper;
        private readonly DelegationInfoRepository _groupRepository;
        private readonly TaskAssignmentRepository _taskAssignmentRep;
        private readonly AirTicketResRepository _airTicketResRep;

        public GroupsController(IMapper mapper, GrpScheduleRepository grpScheduleRep, DelegationInfoRepository groupRepository, TaskAssignmentRepository taskAssignmentRep, AirTicketResRepository airTicketResRep)
        {
            _mapper = mapper;
            _grpScheduleRep = grpScheduleRep;
            _groupRepository = groupRepository;
            _taskAssignmentRep = taskAssignmentRep;
            _airTicketResRep = airTicketResRep;
        }

        #region 流程管控

        /// <summary>
        /// 获取团组流程管控信息
        /// </summary>
        /// <param name="paras">参数Json字符串</param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> PostSearchGrpSchedule(JsonDtoBase _jsonDto)
        {
            if (string.IsNullOrEmpty(_jsonDto.Paras))
            {
                return Ok(JsonView(false, "参数为空"));
            }

            Grp_ScheduleDto _ScheduleDto = JsonConvert.DeserializeObject<Grp_ScheduleDto>(_jsonDto.Paras);
            if (_ScheduleDto != null)
            {
                if (_ScheduleDto.SearchType == 2)//获取列表
                {
                    List<Grp_ScheduleView> _grpScheduleViewList = await _grpScheduleRep.GetViewList_GrpSchedule(_ScheduleDto);
                    return Ok(JsonView(_grpScheduleViewList));
                }
                else//获取对象
                {
                    Grp_ScheduleCombinView _grpScheduleView = await _grpScheduleRep.GetView_GrpSchedule(_ScheduleDto);
                    if (_grpScheduleView != null)
                    {
                        return Ok(JsonView(_grpScheduleView));
                    }
                }
            }
            else
            {
                return Ok(JsonView(false, "参数反序列化失败"));
            }

            return Ok(JsonView(false, "暂无数据！"));
        }

        /// <summary>
        /// 修改团组流程管控详细表数据
        /// </summary>
        /// <param name="paras"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> PostUpdateGrpScheduleDetail(Grp_ScheduleDetailUpdDto dto)
        {
            Grp_ScheduleDetailInfo _detail = _mapper.Map<Grp_ScheduleDetailInfo>(dto);
            var result = await _grpScheduleRep._sqlSugar.Updateable<Grp_ScheduleDetailInfo>()
                .SetColumns(it => it.Duty == _detail.Duty)
                .SetColumns(it => it.ExpectBeginDt == _detail.ExpectBeginDt)
                .SetColumns(it => it.ExpectEndDt == _detail.ExpectEndDt)
                .SetColumns(it => it.JobContent == _detail.JobContent)
                .SetColumns(it => it.Remark == _detail.Remark)
                .SetColumns(it => it.StepStatus == _detail.StepStatus)
                .Where(s => s.Id == dto.Id)

                //.UpdateColumns(s => new { s.Duty, s.ExpectBeginDt, s.ExpectEndDt, s.JobContent, s.Remark, s.StepStatus })
                .ExecuteCommandAsync();
            if (result > 0)
            {
                return Ok(JsonView(true, "保存成功！"));
            }

            return Ok(JsonView(false, "保存失败！"));
        }

        /// <summary>
        /// 删除团组流程管控详细表数据，删除人Id请放在Duty
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<ActionResult> PostDeleteGrpScheduleDetail(Grp_ScheduleDetailUpdDto dto)
        {
            Grp_ScheduleDetailInfo _detail = _mapper.Map<Grp_ScheduleDetailInfo>(dto);
            _detail.IsDel = 1;
            _detail.DeleteUserId = dto.Duty;
            _detail.DeleteTime = DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss");
            var result = await _grpScheduleRep._sqlSugar.Updateable<Grp_ScheduleDetailInfo>()
               .SetColumns(it => it.IsDel == _detail.IsDel)
               .SetColumns(it => it.DeleteUserId == _detail.DeleteUserId)
               .SetColumns(it => it.DeleteTime == _detail.DeleteTime)
               .Where(it => it.Id == dto.Id)

               //.UpdateColumns(s => new { s.IsDel, s.DeleteUserId, s.DeleteTime })
               //.WhereColumns(s => s.Id == dto.Id)
               .ExecuteCommandAsync();
            if (result > 0)
            {
                return Ok(JsonView(true, "删除成功！"));
            }

            return Ok(JsonView(false, "删除失败！"));
        }

        /// <summary>
        /// 增加团组流程管控详细表数据
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<ActionResult> PostInsertGrpScheduleDetail(Grp_ScheduleDetailInsertDto dto)
        {
            Grp_ScheduleDetailInfo _detail = _mapper.Map<Grp_ScheduleDetailInfo>(dto);
            if (DateTime.Now < _detail.ExpectBeginDt)
            {
                _detail.StepStatus = 0;
            }
            else
            {//若大于设置时间，不考虑设置的预计结束日期，统一视为进行中
                _detail.StepStatus = 1;
            }
            var result = await _grpScheduleRep._sqlSugar.Insertable(_detail).ExecuteReturnIdentityAsync();
            if (result > 0)
            {
                Grp_ScheduleDetailView _result = await _grpScheduleRep.GetInsertBackData(result);

                return Ok(JsonView(true, "添加成功！", _result));
            }

            return Ok(JsonView(false, "添加失败！"));
        }

        #endregion

        #region 团组基本信息

        /// <summary>
        ///  接团信息列表
        /// </summary>
        /// <param name="dto">团组列表请求dto</param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GetGroupList(GroupListDto dto)
        {
            var groupData = await _groupRepository.GetGroupList(dto);
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }

            return Ok(JsonView(groupData.Data));
        }

        /// <summary>
        ///  接团信息详情
        /// </summary>
        /// <param name="dto">团组info请求dto</param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GetGroupInfo(GroupInfoDto dto)
        {
            var groupData = await _groupRepository.GetGroupInfo(dto);
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }

            return Ok(JsonView(groupData.Data));
        }

        /// <summary>
        /// 接团信息 编辑添加
        /// 基础信息数据源
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GroupEditBasicSource(GroupListDto dto)
        {

            var groupData = await _groupRepository.GroupEditBasicSource(dto);
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }
            return Ok(JsonView(groupData.Data));

        }

        /// <summary>
        /// 接团信息 操作(增改)
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GroupOperation(GroupOperationDto dto)
        {
            try
            {
                var groupData = await _groupRepository.GroupOperation(dto);
                if (groupData.Code != 0)
                {
                    return Ok(JsonView(false, groupData.Msg));
                }

                return Ok(JsonView(true));
            }
            catch (Exception ex)
            {

                Logs("[response]" + JsonConvert.SerializeObject(dto));
                Logs(ex.Message);
                return Ok(JsonView(false, ex.Message));
            }
        }

        /// <summary>
        /// 接团信息 操作(删除)
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GroupDel(GroupDelDto dto)
        {
            try
            {
                var groupData = await _groupRepository.GroupDel(dto);
                if (groupData.Code != 0)
                {
                    return Ok(JsonView(false, groupData.Msg));
                }

                return Ok(JsonView(true));
            }
            catch (Exception ex)
            {

                Logs("[response]" + JsonConvert.SerializeObject(dto));
                Logs(ex.Message);
                return Ok(JsonView(false, ex.Message));
            }
        }

        /// <summary>
        /// 获取团组销售报价号
        /// 团组添加时 使用
        /// </summary>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GetGroupSalesQuoteNo()
        {
            var groupData = await _groupRepository.GetGroupSalesQuoteNo();
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }
            object salesQuoteNo = new
            {
                SalesQuoteNo = groupData.Data
            };

            return Ok(JsonView(salesQuoteNo));
        }

        /// <summary>
        /// 设置确认出团
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> SetConfirmationGroup(ConfirmationGroupDto dto)
        {
            var groupData = await _groupRepository.ConfirmationGroup(dto);
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }

            GroupStepForDelegation.CreateWorkStep(dto.GroupId); //创建管控流程

            return Ok(JsonView(groupData.Data));
        }

        /// <summary>
        /// 获取团组名称 List
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GetGroupNameList(GroupNameDto dto)
        {
            var groupData = await _groupRepository.GetGroupNameList(dto);
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }

            return Ok(JsonView(groupData.Data, groupData.Data.Count));
        }

        /// <summary>
        /// 获取团组名称data  And 签证国别Data
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GetGroupNameAndVisaNationality(GroupNameDto dto)
        {
            var groupData = await _groupRepository.GetGroupNameAndVisaNationality(dto);
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }


            return Ok(JsonView(groupData.Data));
        }

        #endregion

        #region 团组&签证

        /// <summary>
        ///  根据团组Id获取签证客户信息List
        /// </summary>
        /// <param name="dto">请求dto</param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GetCrmByGroupId(ClientByGroupIdDto dto)
        {
            var groupData = await _groupRepository.GetCrmByGroupId(dto);
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }

            return Ok(JsonView(groupData.Data));
        }



        #endregion

        #region 团组任务分配
        /// <summary>
        /// 团组任务分配初始化
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GetTaskAssignmen()
        {
            var groupData = await _taskAssignmentRep.GetTaskAssignmen();
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }
            return Ok(JsonView(true, groupData.Msg, groupData.Data));
        }

        /// <summary>
        /// 团组任务分配查询
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> TaskAssignmenQuery(TaskAssignmenQueryDto dto)
        {
            var groupData = await _taskAssignmentRep.TaskAssignmenQuery(dto);
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }
            return Ok(JsonView(true, groupData.Msg, groupData.Data));
        }


        /// <summary>
        /// 团组任务分配操作
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> GetTaskAssignmenOp(TaskAssignmenDto dto)
        {
            Result groupData = await _taskAssignmentRep.GetTaskAssignmenOp(dto);
            if (groupData.Code != 0)
            {
                return Ok(JsonView(false, groupData.Msg));
            }
            return Ok(JsonView(true, groupData.Msg, groupData.Data));
        }
        #endregion

        #region 团组费用审核

        /// <summary>
        /// 获取团组费用审核
        /// </summary>
        /// <param name="paras">参数Json字符串</param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> PostSearchGrpCreditCardPayment(Search_GrpCreditCardPaymentDto _dto)
        {
            if (_dto.DiId < 1)
            {
                return Ok(JsonView(false, "团组Id为空"));
            }
            Grp_CreditCardPaymentView _view = new Grp_CreditCardPaymentView();

            #region 团组基本信息

            Grp_DelegationInfo _delegation = _groupRepository.Query<Grp_DelegationInfo>(s => s.Id == _dto.DiId).First();
            if (_delegation == null)
            {
                _view.ClientName = _delegation.ClientName;
                _view.DiId = _dto.DiId;
                _view.TeamName = _delegation.TeamName;
                _view.VisitCountry = _delegation.VisitCountry;
                _view.VisitDate = _delegation.VisitStartDate.ToString("yyyy-MM-dd") + " ~ " + _delegation.VisitEndDate.ToString("yyyy-MM-dd");
                _view.VisitDays = _delegation.VisitDays;
                _view.VisitPNumber = _delegation.VisitPNumber;
            }
            else
            {
                return Ok(JsonView(false, "团组Id为空"));
            }

            #endregion

            #region 费用清单

            //缺少IF的语法糖 CTable
            List<Grp_CreditCardPayment> entityList = _groupRepository
                .Query<Grp_CreditCardPayment>(s => s.DIId == _dto.DiId && s.CTable == _dto.Label && s.IsAuditGM == _dto.AuditStatus && s.IsDel == 0 && s.CreateUserId > 0)
                .ToList();

            List<Grp_CreditCardPaymentDetailView> detailList = new List<Grp_CreditCardPaymentDetailView>();
            decimal CNY = 0;
            decimal PayCNY = 0;
            decimal BalanceCNY = 0;
            decimal YSFYCNY = 0;

            decimal USD = 0;
            decimal PayUSD = 0;
            decimal BalanceUSD = 0;
            decimal YSFYUSD = 0;

            decimal EUR = 0;
            decimal PayEUR = 0;
            decimal BalanceEUR = 0;
            decimal YSFYEUR = 0;

            foreach (var entity in entityList)
            {
                Grp_CreditCardPaymentDetailView _detail = new Grp_CreditCardPaymentDetailView();

                if (entity.CTable != 85) continue;

                /*
                 * Bus名称
                 */
                _detail.BusName = "";

                /*
                 *费用所属
                 */
                switch (entity.CTable)
                {
                    case 85:
                        Grp_AirTicketReservations jpRes = _groupRepository.Query<Grp_AirTicketReservations>(s => s.Id == entity.CId).First();
                        if (jpRes != null)
                        {
                            string FlightsDescription = jpRes.FlightsDescription;
                            string PriceDescription = jpRes.PriceDescription;
                            _detail.PriceMsgContent = "航班号：" + jpRes.FlightsCode + "<br/>城市A-B：" + jpRes.FlightsCity + "<br/>航班描述：" + FlightsDescription.Replace("\r\n", "<br />") + "<br/>" + "价格描述：" + PriceDescription;
                            _detail.PriceNameContent = "(" + jpRes.FlightsCode + ")";
                        }
                        break;
                    case 79:
                        _detail.BusName = "待增加";
                        break;

                    default:
                        break;
                }

                /*
                 * 费用模块
                 */
                Sys_SetData sdPriceName = _groupRepository.Query<Sys_SetData>(s => s.Id == entity.CTable).First();
                if (sdPriceName != null)
                {
                    _detail.PriceName = sdPriceName.Name;
                }

                /*
                 * 应付款金额	
                 */
                Sys_SetData sdPaymentCurrency_WaitPay = _groupRepository.Query<Sys_SetData>(s => s.Id == entity.PaymentCurrency).First();
                string PaymentCurrency_WaitPay = "Unknown";
                if (sdPaymentCurrency_WaitPay != null)
                {
                    PaymentCurrency_WaitPay = sdPaymentCurrency_WaitPay.Name;
                }
                _detail.WaitPay = entity.PayMoney.ToString("#0.00") + " " + PaymentCurrency_WaitPay;

                /*
                 * 此次付款金额
                 */
                decimal CurrPayStr = 0;
                if (entity.PayPercentage == 0)
                {
                    if (entity.PayThenMoney != 0)
                        CurrPayStr = entity.PayThenMoney * decimal.Parse(entity.DayRate);
                }
                else
                {
                    CurrPayStr = entity.PayMoney * (decimal.Parse(entity.PayPercentage.ToString("#0.00")) / 100 * decimal.Parse(entity.DayRate));
                }
                _detail.CurrPay = CurrPayStr.ToString("#0.00") + " CNY";

                /*
                 * 剩余尾款
                 */
                decimal BalanceStr = 0;
                if (entity.PayMoney - (CurrPayStr / decimal.Parse(entity.DayRate)) < 0.01M)
                    BalanceStr = 0;
                else
                    BalanceStr = (entity.PayMoney - CurrPayStr / decimal.Parse(entity.DayRate));

                _detail.Balance = BalanceStr.ToString("#0.00") + " " + PaymentCurrency_WaitPay;

                /*
                 * 申请人
                 */
                string operatorName = "无";
                Sys_Users _opUser = _groupRepository.Query<Sys_Users>(s => s.CreateUserId == entity.CreateUserId).First();
                if (_opUser != null)
                {
                    operatorName = _opUser.CnName;
                }
                _detail.OperatorName = operatorName;

                /*
                * 审核人
                */
                string auditOperatorName = "Unknown";
                if (entity.AuditGMOperate == 0)
                    auditOperatorName = "无";
                else if (entity.AuditGMOperate == 4)
                    auditOperatorName = "自动审核";
                else
                {
                    Sys_Users _adUser = _groupRepository.Query<Sys_Users>(s => s.CreateUserId == entity.AuditGMOperate).First();
                    if (_adUser != null)
                    {
                        auditOperatorName = _adUser.CnName;
                    }
                }
                _detail.AuditOperatorName = auditOperatorName;

                /*
                 * 
                 * *超预算比例
                 */
                string overBudgetStr = "";

                if (entity.ExceedBudget == -1)
                    overBudgetStr = sdPriceName.Name + "尚无预算";
                else if (entity.ExceedBudget == 0)
                    overBudgetStr = "未超预算";
                else
                    overBudgetStr = entity.ExceedBudget.ToString("P");
                _detail.OverBudget = overBudgetStr;


                /*
                 * 费用总计
                 */


                if (entity.PaymentCurrency == 48)
                {
                    CNY += entity.PayMoney;
                    PayCNY += CurrPayStr;
                    BalanceCNY += BalanceStr;
                    YSFYCNY += CurrPayStr;
                }
                if (entity.PaymentCurrency == 49)
                {
                    USD += entity.PayMoney;
                    PayUSD += CurrPayStr;
                    BalanceUSD += BalanceStr;
                    YSFYUSD += CurrPayStr;
                }
                if (entity.PaymentCurrency == 51)
                {
                    EUR += entity.PayMoney;
                    PayEUR += CurrPayStr;
                    BalanceEUR += BalanceStr;
                    YSFYEUR += CurrPayStr;
                }

                _detail.TotalStr1 = string.Format(@"应付款总金额：{0}CNY&nbsp;|&nbsp;{1}USD&nbsp;|&nbsp;{2}EUR", CNY, USD, EUR);
                _detail.TotalStr2 = string.Format(@"此次付款总金额：{0}CNY&nbsp;|&nbsp;{1}USD&nbsp;|&nbsp;{2}EUR", PayCNY, PayUSD, PayEUR);
                _detail.TotalStr3 = string.Format(@"目前剩余尾款总金额：{0}CNY&nbsp;|&nbsp;{1}USD&nbsp;|&nbsp;{2}EUR", BalanceCNY, BalanceUSD, BalanceEUR);
                _detail.TotalStr4 = string.Format(@"已审费用总额：{0}CNY&nbsp;|&nbsp;{1}USD&nbsp;|&nbsp;{2}EUR", YSFYCNY, YSFYUSD, YSFYEUR);


                detailList.Add(_detail);

            }

            #endregion
            _view.DetailList = new List<Grp_CreditCardPaymentDetailView>(detailList);

            return Ok(JsonView(_view));
        }


        /// <summary>
        /// 获取团组费用审核
        /// </summary>
        /// <param name="paras">参数Json字符串</param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> PostAuditGrpCreditCardPayment(Edit_GrpCreditCardPaymentDto _dto)
        {
            Grp_CreditCardPayment _detail = _mapper.Map<Grp_CreditCardPayment>(_dto);
            DateTime dtNow = DateTime.Now;
            var result = await _grpScheduleRep._sqlSugar.Updateable<Grp_CreditCardPayment>()
                .SetColumns(it => it.IsAuditGM == _dto.AuditCode)
                .SetColumns(it => it.AuditGMOperate == _dto.User)
                .SetColumns(it => it.AuditGMDate == dtNow)
                .Where(s => s.Id == _dto.CreditId)
                .ExecuteCommandAsync();
            if (result > 0)
            {
                return Ok(JsonView(true, "保存成功！"));
            }

            return Ok(JsonView(false, "保存失败！"));
        }

        #endregion

        #region 机票费用录入
        /// <summary>
        /// 机票录入当前登录人可操作团组
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> AirTicketResSelect(AirTicketResDto dto)
        {
            try
            {
                Result groupData = await _airTicketResRep.AirTicketResSelect(dto);
                if (groupData.Code != 0)
                {
                    return Ok(JsonView(false, groupData.Msg));
                }
                return Ok(JsonView(true, groupData.Msg, groupData.Data));
            }
            catch (Exception ex)
            {
                return Ok(JsonView(false, "程序错误！"));
                throw;
            }
        }
        /// <summary>
        /// 机票费用录入列表
        /// </summary>
        /// <param name="dto"></param>
        /// <returns></returns>
        [HttpPost]
        [ProducesResponseType(typeof(JsonView), StatusCodes.Status200OK)]
        public async Task<IActionResult> AirTicketResList(AirTicketResListDto dto)
        {
            try
            {
                Result groupData = await _airTicketResRep.AirTicketResList(dto);
                if (groupData.Code != 0)
                {
                    return Ok(JsonView(false, groupData.Msg));
                }
                return Ok(JsonView(true, groupData.Msg, groupData.Data));
            }
            catch (Exception ex)
            {
                return Ok(JsonView(false, "程序错误！"));
                throw;
            }
        }

        #endregion
    }
}
