﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace OASystem.Domain.Entities.Resource
{
    /// <summary>
    /// 物料供应商
    /// </summary>
    [SugarTable("Res_ItemVendor")]
    public class Res_ItemVendor : EntityBase
    {
        /// <summary>
        /// 供应商公司经营范围,SetDataId拼接，请注意拼接格式统一为英文逗号
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "varchar(50)")]
        public string BusRange { get; set; }
        /// <summary>
        /// 供应商名称(公司全称)
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "varchar(100)")]
        public string FullName { get; set; }

        /// <summary>
        /// 供应商简称
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "varchar(50)")]
        public string ShortName { get; set; }

        /// <summary>
        /// 供应商联系地址
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "varchar(100)")]
        public string Address { get; set; }

        /// <summary>
        /// 供应商联系人
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "varchar(50)")]
        public string Linker { get; set; }

        /// <summary>
        /// 供应商联系人职位
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "varchar(50)")]
        public string Job { get; set; }

        /// <summary>
        /// 供应商联系方式
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "varchar(50)")]
        public string Mobile { get; set; }

    }

    [SugarTable("Res_ItemType")]
    public class Res_ItemTypeInfo : EntityBase
    {
        [SugarColumn(IsNullable = true, ColumnDataType = "int")]
        public int SdId { get; set; }

        [SugarColumn(IsNullable = true, ColumnDataType = "varchar(50)")]
        public string TypeName { get; set; }

    }

    /// <summary>
    /// 物料供应详细信息表
    /// </summary>
    [SugarTable("Res_ItemDetail")]
    public class Res_ItemDetailInfo : EntityBase
    {
        /// <summary>
        /// 物料供应商
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "int")]
        public int VendorId { get; set; }

        /// <summary>
        /// 物料名称
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "varchar(50)")]
        public string ItemName { get; set; }

        /// <summary>
        /// 物料类型Id
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "int")]
        public int ItemTypeId { get; set; }

        /// <summary>
        /// 最低单价
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "decimal(9,2)")]
        public decimal MinRate { get; set; }

        /// <summary>
        /// 最低价格维护时间
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "datetime")]
        public DateTime MinDt { get; set; }

        /// <summary>
        /// 最高单价
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "decimal(9,2)")]
        public decimal MaxRate { get; set; }

        /// <summary>
        /// 最高价格维护时间
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "datetime")]
        public DateTime MaxDt { get; set; }

        /// <summary>
        /// 当前单价
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "decimal(9,2)")]
        public decimal CurrRate { get; set; }

        /// <summary>
        /// 当前价格维护时间
        /// </summary>
        [SugarColumn(IsNullable = true, ColumnDataType = "datetime")]
        public DateTime CurrDt { get; set; }
    }
}
