﻿using AutoMapper;
using OASystem.Domain;
using OASystem.Domain.Dtos.Resource;
using OASystem.Domain.Entities.Groups;
using OASystem.Domain.Entities.Resource;
using OASystem.Domain.ViewModels.Resource;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace OASystem.Infrastructure.Repositories.Resource
{
    public class LocalGuideDataRepository : BaseRepository<Res_LocalGuideData, LocalGuideDataView>
    {
        private readonly IMapper _mapper;
        public LocalGuideDataRepository(SqlSugarClient sqlSugar, IMapper mapper) : base(sqlSugar)
        {
            _mapper=mapper;
        }
        public async Task<Result> LocalGuideOperation(LocalGuideOperationDto dto)
        {
            Result result = new Result() { Code = -2, Msg = "未知错误" };
            try
            {
                if (dto.Status == 1)//添加
                {
                    string selectSql = string.Format(@"select * from Res_LocalGuideData where UnitArea='{0}' and UnitName='{1}' and Contact='{2}' and ContactTel='{3}'"
                                                       , dto.UnitArea, dto.UnitName, dto.Contact, dto.ContactTel);
                    var LocalGuideData = await _sqlSugar.SqlQueryable<Res_LocalGuideData>(selectSql).FirstAsync();//查询是否存在
                    if (LocalGuideData != null)
                    {
                         return result = new Result() { Code = -1, Msg = "该信息已存在，请勿重复添加！" };
                         
                    }
                    else//不存在，可添加
                    {
                        Res_LocalGuideData _LocalGuideDat = _mapper.Map<Res_LocalGuideData>(dto);
                        int id = await AddAsyncReturnId(_LocalGuideDat);
                        if (id == 0)
                        {
                            return result = new Result() { Code = -1, Msg = "添加失败！" };

                        }
                         result = new Result() { Code = 0, Msg = "添加成功！", Data = new { Id = id } };
                    }
                }
                else if(dto.Status == 2)//修改
                {
                    bool res = await UpdateAsync(a => a.Id == dto.Id, a => new Res_LocalGuideData
                    {
                        UnitArea = dto.UnitArea,
                        UnitName = dto.UnitName,
                        Address = dto.Address,
                        Contact = dto.Contact,
                        ContactTel = dto.ContactTel,
                        ContactEmail = dto.ContactEmail,
                        ContactFax = dto.ContactFax,
                        OtherInfo = dto.OtherInfo,
                        Score = dto.Score,
                        SuitScore = dto.SuitScore,
                        ServeScore = dto.ServeScore,
                        TalkProScore = dto.TalkProScore,
                        TimeScore = dto.TimeScore,
                        FitScore = dto.FitScore,
                        StrainScore = dto.StrainScore,
                        LocalAndChineseScore = dto.LocalAndChineseScore,
                        Remark = dto.Remark,
                    });
                    if (!res)
                    {
                        return result = new Result() { Code = -1, Msg = "修改失败！" };
                    }
                    result = new Result() { Code = 0, Msg = "修改成功！" };
                }
                else
                {
                    return  result = new Result() { Code = -1, Msg = "请传入Status参数，1添加 2修改！" };
                }
            }
            catch (Exception ex)
            {
                return result = new Result() { Code = -2, Msg = "程序错误！" };
            }
            return result;
        }

        public async Task<Result> QueryLocalGuide(QueryLocalGuide dto)
        {
            Result result = new Result() { Code = -2, Msg = "未知错误" };
            try
            {
                string sqlWhere = string.Empty;
                if (!string.IsNullOrWhiteSpace(dto.UnitName))
                {
                    sqlWhere += string.Format(@" And UnitName like '%{0}%'", dto.UnitName);
                }
                if (!string.IsNullOrWhiteSpace(dto.UnitArea) && dto.UnitArea != "全部")
                {
                    sqlWhere += string.Format(@" And UnitArea like '%{0}%'", dto.UnitArea);
                }
                if (!string.IsNullOrWhiteSpace(dto.Contact))
                {
                    sqlWhere += string.Format(@" And Contact like '%{0}%'", dto.Contact);
                }
                if (!string.IsNullOrWhiteSpace(dto.ContactTel))
                {
                    sqlWhere += string.Format(@" And ContactTel like '%{0}%'", dto.ContactTel);
                }
                sqlWhere += string.Format(@" And IsDel={0}", 0);
                if (!string.IsNullOrEmpty(sqlWhere.Trim()))
                {
                    Regex r = new Regex("And");
                    sqlWhere = r.Replace(sqlWhere, "Where", 1);
                }
                if (dto.PortType == 1)
                {
                    string sql = string.Format(@"select * from Res_LocalGuideData {0}", sqlWhere);
                    List<Res_LocalGuideData> LocalGuideData = await _sqlSugar.SqlQueryable<Res_LocalGuideData>(sql).ToListAsync();
                    if (LocalGuideData.Count == 0)
                    {
                        return result = new Result() { Code = -1, Msg = "暂无数据" };
                    }
                    LocalGuideData = LocalGuideData.OrderByDescending(x => x.CreateTime).ToList();

                    if (dto.PageSize == 0 || dto.PageIndex == 0)
                    {
                        return result = new Result()
                        {
                            Code = 0,
                            Msg = "查询成功",
                            Data = LocalGuideData,
                        };
                    }
                    else
                    {
                        int count = LocalGuideData.Count;
                        float totalPage = (float)count / dto.PageSize;//总页数
                        if (totalPage == 0) totalPage = 1;
                        else totalPage = (int)Math.Ceiling((double)totalPage);

                        List<Res_LocalGuideData> ListData = new List<Res_LocalGuideData>();
                        for (int i = 0; i < dto.PageSize; i++)
                        {
                            var RowIndex = i + (dto.PageIndex - 1) * dto.PageSize;
                            if (RowIndex < LocalGuideData.Count)
                            {
                                ListData.Add(LocalGuideData[RowIndex]);
                            }
                            else
                            {
                                break;
                            }
                        }
                        return result = new Result()
                        {
                            Code = 0,
                            Msg = "查询成功",
                            Data = new { pageCount = count, totalPage = (int)totalPage, pageIndex = dto.PageIndex, pageSize = dto.PageSize, pageSource = ListData },
                        };
                    }

                }
                else if (dto.PortType == 2)
                {
                    string sql = string.Format(@"select * from Res_LocalGuideData {0}", sqlWhere);
                    List<Res_LocalGuideData> LocalGuideData = await _sqlSugar.SqlQueryable<Res_LocalGuideData>(sql).ToListAsync();
                    if (LocalGuideData.Count == 0)
                    {
                        return result = new Result() { Code = -1, Msg = "暂无数据" };
                    }
                    LocalGuideData = LocalGuideData.OrderByDescending(x => x.CreateTime).ToList();

                    if (dto.PageSize == 0 && dto.PageIndex == 0)
                    {
                        return result = new Result()
                        {
                            Code = 0,
                            Msg = "查询成功",
                            Data = LocalGuideData,
                        };
                    }
                    else
                    {
                        int count = LocalGuideData.Count;
                        float totalPage = (float)count / dto.PageSize;//总页数
                        if (totalPage == 0) totalPage = 1;
                        else totalPage = (int)Math.Ceiling((double)totalPage);

                        List<Res_LocalGuideData> ListData = new List<Res_LocalGuideData>();
                        for (int i = 0; i < dto.PageSize; i++)
                        {
                            var RowIndex = i + (dto.PageIndex - 1) * dto.PageSize;
                            if (RowIndex < LocalGuideData.Count)
                            {
                                ListData.Add(LocalGuideData[RowIndex]);
                            }
                            else
                            {
                                break;
                            }
                        }
                        return result = new Result()
                        {
                            Code = 0,
                            Msg = "查询成功",
                            Data = new { pageCount = count, totalPage = (int)totalPage, pageIndex = dto.PageIndex, pageSize = dto.PageSize, pageSource = ListData },
                        };
                    }
                }
                else
                {
                    return result = new Result() { Code = -2, Msg = "请传入PortType参数！1:Web，2:Android,3:IOS" };
                }
            }
            catch (Exception)
            {
                return result;
                throw;
            }

        }
    }
}
